@@ -2,10 +2,11 @@ import Algorithmia
 import os
 from Algorithmia.errors import DataApiError
 from Algorithmia.algo_response import AlgoResponse
+from Algorithmia.util import md5_for_file, md5_for_str
 import json, re, requests, six
 import toml
 import shutil
-
+from time import time
 
 class CLI:
     def __init__(self):
@@ -101,7 +102,7 @@ class CLI:
         elif (options.binary_file != None):
             # binary file
             with open(options.binary_file, "rb") as f:
-                algo_inputs = bytes(f.read())
+                algo_input = bytes(f.read())
             key = self.getAPIkey(options.profile)
             content = 'application/octet-stream'
 
@@ -245,6 +246,31 @@ class CLI:
 
         return result
 
+    # algo freeze
+    def freezeAlgo(self, client, manifest_path="model_manifest.json"):
+        if os.path.exists(manifest_path):
+            with open(manifest_path, 'r') as f:
+                manifest_file = json.load(f)
+            manifest_file['timestamp'] = str(time())
+            required_files = manifest_file['required_files']
+            optional_files = manifest_file['optional_files']
+            for i in range(len(required_files)):
+                uri = required_files[i]['source_uri']
+                local_file = client.file(uri).getFile(as_path=True)
+                md5_checksum = md5_for_file(local_file)
+                required_files[i]['md5_checksum'] = md5_checksum
+            for i in range(len(optional_files)):
+                uri = required_files[i]['source_uri']
+                local_file = client.file(uri).getFile(as_path=True)
+                md5_checksum = md5_for_file(local_file)
+                required_files[i]['md5_checksum'] = md5_checksum
+            lock_md5_checksum = md5_for_str(str(manifest_file))
+            manifest_file['lock_checksum'] = lock_md5_checksum
+            with open('model_manifest.json.freeze', 'w') as f:
+                json.dump(manifest_file, f)
+        else:
+            print("Expected to find a model_manifest.json file, none was discovered in working directory")
+
     # algo cp <src> <dest>
     def cp(self, src, dest, client):
 
